Enjoy the bridge game

## Introduction

this is designed to be used (copy/paste) for HTML/Microsoft Word

Designed by Larry Cai and produced by bridge-utils/pbn2html, version 0.1.6

Credit to BridgeComposer Version 5.83 (64 bit)

### 群组IMP赛 20201219 牌号 2/8

4 ♠ by North Lead: ♦K |
♠ | A K 9 4 2
♥ | J 9 6 3
♦ | —
♣ | A K 10 6
♠ | 10 8 7 6
♥ | K 10 8
♦ | 10 7 3
♣ | Q 7 5
| N |
W | → | E
| S |
♠ | 3
♥ | A 4
♦ | K Q 9 6 4
♣ | J 9 8 4 2
♠ | Q J 5
♥ | Q 7 5 2
♦ | A J 8 5 2
♣ | 3

West | North | East | South
|  | Pass | Pass
| Pass | 1 ♠ | Pass | 2 ♣ | Pass | 4 ♠ | Pass | Pass | Pass